<?php
/**
 * Plugin Name: WP Immo Sync
 * Plugin URI: https://wp.immosync.com
 * Description: Importer et synchroniser vos biens dans wordpress avec votre logiciel immobilier (Whise, Omnicasa, Sweepbright, Activimmo)
 * Version: 1.7.5
 * Author: Jeremy Jamar
 * Author URI: https://www.linkedin.com/in/jeremyjamar
 * License: GPL2
 */

namespace WPIS;

require_once 'class/trait-estate-post-metas.php';
require_once 'class/class-wpis-admin.php';
require_once 'class/class-wpis-client.php';
require_once 'class/class-wpis-post-types.php';
require_once 'class/class-wpis-short-tags.php';
require_once 'class/class-api-admin.php';
require_once 'class/class-api-public.php';
require_once 'class/class-wpis-settings-management.php';
require_once 'class/class-wpis-logger.php';
require_once 'class/class-wpis-updater.php';
require_once 'api/ImmosyncClient.php';

require_once ABSPATH . 'wp-admin/includes/upgrade.php';

class WPIS {

    public const API_URL = 'https://api.immosync.com';

    public function __construct(){

        Admin::init();
        Client::init();
        PostTypes::init();
        ShortTags::init();
        ApiAdmin::init();
        ApiPublic::init();

        $this->wp_db = $GLOBALS['wpdb'];
		$this->wp_table_connexion = $this->wp_db->prefix . 'wpis_connexion';
		$this->wp_table_settings = $this->wp_db->prefix . 'wpis_settings';

        register_activation_hook( __FILE__ , [$this, 'wpis_install']);
        register_deactivation_hook( __FILE__, [$this, 'wpis_uninstall']);
    }

    public function wpis_install() {

        $charset_collate = $this->wp_db->get_charset_collate();

        $create_table_connexion = "CREATE TABLE IF NOT EXISTS $this->wp_table_connexion (
          access_id tinytext NOT NULL,
          name tinytext NOT NULL,
          account tinytext NOT NULL,
          token TEXT NOT NULL,
          activated_at TIMESTAMP NOT NULL
        ) $charset_collate;";
        $this->wp_db->query( $create_table_connexion );

        $create_table_settings = "CREATE TABLE IF NOT EXISTS $this->wp_table_settings (
          name VARCHAR(50) UNIQUE NOT NULL,
          value VARCHAR(50),
          updated_at TIMESTAMP NOT NULL
        ) $charset_collate;";
        $this->wp_db->query( $create_table_settings );
    }

    public function wpis_uninstall() {
        $sql = 'DROP TABLE IF EXISTS ' . $this->wp_table_connexion . ';';
        $this->wp_db->query($sql);
        $sql = 'DROP TABLE IF EXISTS ' . $this->wp_table_settings . ';';
        $this->wp_db->query($sql);
    }
}

new WPIS();